==> huaweicloudsdkcdn-3.0.50-py2.py3-none-any.whl: huaweicloudsdkcdn/v1/model/update_private_bucket_access_request.py <==
# coding: utf-8

import pprint
import re

import six





class UpdatePrivateBucketAccessRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'domain_id': 'str',
        'body': 'UpdatePrivateBucketAccessBody'
    }

    attribute_map = {
        'domain_id': 'domain_id',
        'body': 'body'
    }

    def __init__(self, domain_id=None, body=None):
        """UpdatePrivateBucketAccessRequest - a model defined in huaweicloud sdk"""
        
        

        self._domain_id = None
        self._body = None
        self.discriminator = None

        self.domain_id = domain_id
        if body is not None:
            self.body = body

    @property
    def domain_id(self):
        """Gets the domain_id of this UpdatePrivateBucketAccessRequest.

        加速域名id。获取方法请参见查询加速域名。

        :return: The domain_id of this UpdatePrivateBucketAccessRequest.
        :rtype: str
        """
        return self._domain_id

    @domain_id.setter
    def domain_id(self, domain_id):
        """Sets the domain_id of this UpdatePrivateBucketAccessRequest.

        加速域名id。获取方法请参见查询加速域名。

        :param domain_id: The domain_id of this UpdatePrivateBucketAccessRequest.
        :type: str
        """
        self._domain_id = domain_id

    @property
    def body(self):
        """Gets the body of this UpdatePrivateBucketAccessRequest.


        :return: The body of this UpdatePrivateBucketAccessRequest.
        :rtype: UpdatePrivateBucketAccessBody
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdatePrivateBucketAccessRequest.


        :param body: The body of this UpdatePrivateBucketAccessRequest.
        :type: UpdatePrivateBucketAccessBody
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdatePrivateBucketAccessRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcdn-3.0.52-py2.py3-none-any.whl: huaweicloudsdkcdn/v1/model/update_private_bucket_access_request.py <==
# coding: utf-8

import re
import six





class UpdatePrivateBucketAccessRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'domain_id': 'str',
        'body': 'UpdatePrivateBucketAccessBody'
    }

    attribute_map = {
        'domain_id': 'domain_id',
        'body': 'body'
    }

    def __init__(self, domain_id=None, body=None):
        """UpdatePrivateBucketAccessRequest - a model defined in huaweicloud sdk"""
        
        

        self._domain_id = None
        self._body = None
        self.discriminator = None

        self.domain_id = domain_id
        if body is not None:
            self.body = body

    @property
    def domain_id(self):
        """Gets the domain_id of this UpdatePrivateBucketAccessRequest.

        加速域名id。获取方法请参见查询加速域名。

        :return: The domain_id of this UpdatePrivateBucketAccessRequest.
        :rtype: str
        """
        return self._domain_id

    @domain_id.setter
    def domain_id(self, domain_id):
        """Sets the domain_id of this UpdatePrivateBucketAccessRequest.

        加速域名id。获取方法请参见查询加速域名。

        :param domain_id: The domain_id of this UpdatePrivateBucketAccessRequest.
        :type: str
        """
        self._domain_id = domain_id

    @property
    def body(self):
        """Gets the body of this UpdatePrivateBucketAccessRequest.


        :return: The body of this UpdatePrivateBucketAccessRequest.
        :rtype: UpdatePrivateBucketAccessBody
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdatePrivateBucketAccessRequest.


        :param body: The body of this UpdatePrivateBucketAccessRequest.
        :type: UpdatePrivateBucketAccessBody
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdatePrivateBucketAccessRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
